"""An office router product type."""

from orchestrator.domain.base import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle

from gso.products.product_blocks.office_router import (
    OfficeRouterBlock,
    OfficeRouterBlockInactive,
    OfficeRouterBlockProvisioning,
)


class OfficeRouterInactive(SubscriptionModel, is_base=True):
    """An inactive office router."""

    office_router: OfficeRouterBlockInactive


class OfficeRouterProvisioning(OfficeRouterInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """An office router that is being provisioned."""

    office_router: OfficeRouterBlockProvisioning


class OfficeRouter(OfficeRouterProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An office router that is currently active."""

    office_router: OfficeRouterBlock


class ImportedOfficeRouterInactive(SubscriptionModel, is_base=True):
    """An imported, inactive office router."""

    office_router: OfficeRouterBlockInactive


class ImportedOfficeRouter(
    ImportedOfficeRouterInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING, SubscriptionLifecycle.ACTIVE]
):
    """An imported office router that is currently active."""

    office_router: OfficeRouterBlock
